==> variety_0.7.1.orig.tar.gz: variety-0.7.1/tests/TestQuotationsPageSource.py <==
#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import sys
import os.path
import unittest

sys.path.insert(0, os.path.realpath(os.path.join(os.path.dirname(__file__), "..")))

from jumble.Jumble import Jumble


class TestQuotationsPageSource(unittest.TestCase):
    def test_get_random(self):
        p = Jumble(["../data/plugins"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_random()
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])

    def test_get_for_author(self):
        p = Jumble(["../data/plugins"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_for_author("voltaire")
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])
        self.assertEqual("Voltaire", q[0]["author"])

    def test_get_for_keyword(self):
        p = Jumble(["../data/plugins"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_for_keyword("funny")
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])
        self.assertTrue(q[0]["quote"].lower().find('funny') >= 0)

==> variety_0.8.5.orig.tar.gz: variety-0.8.5/tests/TestQuotationsPageSource.py <==
#!/usr/bin/python3
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import unittest

from jumble.Jumble import Jumble


class TestQuotationsPageSource(unittest.TestCase):
    def test_get_random(self):
        p = Jumble(["variety/plugins/builtin"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_random()
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])

    def test_get_for_author(self):
        p = Jumble(["variety/plugins/builtin"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_for_author("voltaire")
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])
        self.assertEqual("Voltaire", q[0]["author"])

    def test_get_for_keyword(self):
        p = Jumble(["variety/plugins/builtin"])
        p.load()
        source = p.get_plugins(typename="QuotationsPageSource")[0]
        q = source["plugin"].get_for_keyword("funny")
        self.assertTrue(len(q) > 0)
        self.assertEqual("TheQuotationsPage.com", q[0]["sourceName"])
        self.assertTrue(q[0]["quote"].lower().find("funny") >= 0)
